@@ -12,7 +12,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
+import glob
 from typing import TYPE_CHECKING, Any
 
 if TYPE_CHECKING:
@@ -20,6 +20,7 @@ if TYPE_CHECKING:
 
 import json
 import logging
+import os
 import warnings
 from inspect import Signature, signature
 from pathlib import Path
@@ -62,15 +63,15 @@ class FAISSDocumentStore(SQLDocumentStore):
         vector_dim: int = None,
         embedding_dim: int = 768,
         faiss_index_factory_str: str = "Flat",
-        faiss_index: "Optional[faiss.swigfaiss.Index]" = None,
+        faiss_index: Union[dict, faiss.swigfaiss_avx2.IndexFlat] = None,
         return_embedding: bool = False,
-        index_name: str = "document",
+        index_name: Union[str, list] = "document",
         similarity: str = "dot_product",
         embedding_field: str = "embedding",
         progress_bar: bool = True,
         duplicate_documents: str = "overwrite",
-        faiss_index_path: Union[str, Path] = None,
-        faiss_config_path: Union[str, Path] = None,
+        faiss_index_path: Union[str, Path, list] = None,
+        faiss_config_path: Union[str, Path, list] = None,
         isolation_level: str = None,
         **kwargs,
     ):
@@ -119,7 +120,7 @@ class FAISSDocumentStore(SQLDocumentStore):
         """
         # special case if we want to load an existing index from disk
         # load init params from disk and run init again
-        if faiss_index_path is not None:
+        if faiss_index_path:
             sig = signature(self.__class__.__init__)
             self._validate_params_load_from_disk(sig, locals(), kwargs)
             init_params = self._load_init_params_from_config(faiss_index_path, faiss_config_path)
@@ -163,8 +164,11 @@ class FAISSDocumentStore(SQLDocumentStore):
 
         self.faiss_index_factory_str = faiss_index_factory_str
         self.faiss_indexes: Dict[str, faiss.swigfaiss.Index] = {}
-        if faiss_index:
+        if faiss_index and type(index_name) == str:
             self.faiss_indexes[index_name] = faiss_index
+        elif faiss_index and type(index_name) == list:
+            for index in index_name:
+                self.faiss_indexes[index] = faiss_index[index]
         else:
             self.faiss_indexes[index_name] = self._create_new_index(
                 embedding_dim=self.embedding_dim,
@@ -177,6 +181,8 @@ class FAISSDocumentStore(SQLDocumentStore):
         self.embedding_field = embedding_field
 
         self.progress_bar = progress_bar
+        if type(index_name) == list:
+            index_name = index_name[0]
 
         super().__init__(
             url=sql_url, index=index_name, duplicate_documents=duplicate_documents, isolation_level=isolation_level
@@ -185,7 +191,7 @@ class FAISSDocumentStore(SQLDocumentStore):
         self._validate_index_sync()
 
     def _validate_params_load_from_disk(self, sig: Signature, locals: dict, kwargs: dict):
-        allowed_params = ["faiss_index_path", "faiss_config_path", "self", "kwargs"]
+        allowed_params = ["faiss_index_path", "faiss_config_path", "self", "kwargs", "faiss_index", "index_name"]
         invalid_param_set = False
 
         for param in sig.parameters.values():
@@ -282,7 +288,6 @@ class FAISSDocumentStore(SQLDocumentStore):
                     "`FAISSDocumentStore` does not support update in existing `faiss_index`.\n"
                     "Please call `update_embeddings` method to repopulate `faiss_index`"
                 )
-
             vector_id = self.faiss_indexes[index].ntotal
             with tqdm(
                 total=len(document_objects), disable=not self.progress_bar, position=0, desc="Writing Documents"
@@ -301,10 +306,9 @@ class FAISSDocumentStore(SQLDocumentStore):
                     for doc in document_objects[i : i + batch_size]:
                         meta = doc.meta
                         if add_vectors:
-                            meta["vector_id"] = vector_id
+                            meta["vector_id"] = str(vector_id) + "_" + index
                             vector_id += 1
                         docs_to_write_in_sql.append(doc)
-
                     super(FAISSDocumentStore, self).write_documents(
                         docs_to_write_in_sql,
                         index=index,
@@ -328,7 +332,7 @@ class FAISSDocumentStore(SQLDocumentStore):
         batch_size: int = 10000,
     ):
         """
-        Updates the embeddings in the the document store using the encoding model specified in the retriever.
+        Updates the embeddings in the document store using the encoding model specified in the retriever.
         This can be useful if want to add or change the embeddings for your documents (e.g. after changing the retriever config).
 
         :param retriever: Retriever to use to get embeddings for text
@@ -598,8 +602,7 @@ class FAISSDocumentStore(SQLDocumentStore):
             self.normalize_embedding(query_emb)
 
         score_matrix, vector_id_matrix = self.faiss_indexes[index].search(query_emb, top_k)
-        vector_ids_for_query = [str(vector_id) for vector_id in vector_id_matrix[0] if vector_id != -1]
-
+        vector_ids_for_query = [str(vector_id) + "_" + index for vector_id in vector_id_matrix[0] if vector_id != -1]
         documents = self.get_documents_by_vector_ids(vector_ids_for_query, index=index)
 
         # assign query score to each document
@@ -607,12 +610,11 @@ class FAISSDocumentStore(SQLDocumentStore):
             str(v_id): s for v_id, s in zip(vector_id_matrix[0], score_matrix[0])
         }
         for doc in documents:
-            raw_score = scores_for_vector_ids[doc.meta["vector_id"]]
+            raw_score = scores_for_vector_ids[doc.meta["vector_id"].split("_")[0]]
             doc.ann_score = self.finalize_raw_score(raw_score, self.similarity)
 
             if return_embedding is True:
-                doc.embedding = self.faiss_indexes[index].reconstruct(int(doc.meta["vector_id"]))
-
+                doc.embedding = self.faiss_indexes[index].reconstruct(int(doc.meta["vector_id"].split("_")[0]))
         return documents
 
     def save(self, index_path: Union[str, Path], config_path: Optional[Union[str, Path]] = None):
@@ -627,38 +629,70 @@ class FAISSDocumentStore(SQLDocumentStore):
             used by the `load` method to restore the index with the appropriate configuration.
         :return: None
         """
-        if not config_path:
-            index_path = Path(index_path)
+        index_path_dir = index_path
+        if not os.path.exists(index_path_dir):
+            os.mkdir(index_path_dir)
+        for index in self.faiss_indexes.keys():
+            index_path = Path(os.path.join(index_path_dir, str(index)))
             config_path = index_path.with_suffix(".json")
-
-        faiss.write_index(self.faiss_indexes[self.index], str(index_path))
-        with open(config_path, "w") as ipp:
-            json.dump(self.pipeline_config["params"], ipp)
+            faiss.write_index(self.faiss_indexes[index], str(index_path))
+            with open(config_path, "w") as ipp:
+                json.dump(self.pipeline_config["params"], ipp)
 
     def _load_init_params_from_config(
         self, index_path: Union[str, Path], config_path: Optional[Union[str, Path]] = None
     ):
-        if not config_path:
-            index_path = Path(index_path)
-            config_path = index_path.with_suffix(".json")
+        if type(index_path) != list:
+            if not config_path:
+                index_path = Path(index_path)
+                config_path = index_path.with_suffix(".json")
 
-        init_params: dict = {}
-        try:
-            with open(config_path, "r") as ipp:
-                init_params = json.load(ipp)
-        except OSError as e:
-            raise ValueError(
-                f"Can't open FAISS configuration file `{config_path}`. "
-                "Make sure the file exists and the you have the correct permissions "
-                "to access it."
-            ) from e
+            init_params: dict = {}
+            try:
+                with open(config_path, "r") as ipp:
+                    init_params = json.load(ipp)
+                if "index" in init_params:
+                    init_params["index_name"] = init_params["index"]
+                    init_params.pop("index")
+            except OSError as e:
+                raise ValueError(
+                    f"Can't open FAISS configuration file `{config_path}`. "
+                    "Make sure the file exists and the you have the correct permissions "
+                    "to access it."
+                ) from e
+            faiss_index = faiss.read_index(str(index_path))
 
-        faiss_index = faiss.read_index(str(index_path))
-
-        # Add other init params to override the ones defined in the init params file
-        init_params["faiss_index"] = faiss_index
-        init_params["embedding_dim"] = faiss_index.d
+            # Add other init params to override the ones defined in the init params file
+            init_params["faiss_index"] = faiss_index
+            init_params["embedding_dim"] = faiss_index.d
 
+        else:
+            if not config_path:
+                index_path = Path(index_path[0])
+                config_path = index_path.with_suffix(".json")
+            else:
+                config_path = config_path[0]
+            init_params: dict = {}
+            try:
+                with open(config_path, "r") as ipp:
+                    init_params = json.load(ipp)
+                if "index" in init_params:
+                    init_params.pop("index")
+            except OSError as e:
+                raise ValueError(
+                    f"Can't open FAISS configuration file `{config_path}`. "
+                    "Make sure the file exists and the you have the correct permissions "
+                    "to access it."
+                ) from e
+            if type(index_path) == list:
+                init_params["faiss_index"] = {}
+                init_params["index_name"] = []
+                for index in index_path:
+                    faiss_index = faiss.read_index(str(index))
+                    index_name = str(index).split("/")[-1]
+                    init_params["index_name"].append(index_name)
+                    init_params["faiss_index"][index_name] = faiss_index
+                    # Add other init params to override the ones defined in the init params file
         return init_params
 
     @classmethod
@@ -672,4 +706,7 @@ class FAISSDocumentStore(SQLDocumentStore):
         :param config_path: Stored FAISS initial configuration parameters.
             Can be created via calling `save()`
         """
+        if os.path.isdir(index_path):
+            config_path = glob.glob(index_path + "/**/*.json", recursive=True)
+            index_path = [path.replace(".json", "") for path in config_path]
         return cls(faiss_index_path=index_path, faiss_config_path=config_path)
