@@ -31,8 +31,18 @@ from pipelines.nodes.file_converter import (
     PDFToTextOCRConverter,
     TextConverter,
 )
+from pipelines.nodes.llm import ChatGLMBot
+from pipelines.nodes.llm.ernie_bot import ErnieBot
+from pipelines.nodes.llm.history import TruncatedConversationHistory
+from pipelines.nodes.llm.prompt_template import LLMPromptTemplate as PromptTemplate
 from pipelines.nodes.other import JoinDocuments
-from pipelines.nodes.preprocessor import BasePreProcessor, PreProcessor
+from pipelines.nodes.preprocessor import (
+    BasePreProcessor,
+    CharacterTextSplitter,
+    PreProcessor,
+    RecursiveCharacterTextSplitter,
+)
+from pipelines.nodes.prompt import PromptModel, PromptNode, Shaper
 from pipelines.nodes.question_generator import QuestionGenerator
 from pipelines.nodes.ranker import BaseRanker, ErnieRanker
 from pipelines.nodes.reader import BaseReader, ErnieReader
@@ -41,6 +51,7 @@ from pipelines.nodes.retriever import (
     BM25Retriever,
     DensePassageRetriever,
     MultiModalRetriever,
+    WebRetriever,
 )
 from pipelines.nodes.sentiment_analysis import (
     SentaProcessor,
