@@ -14,3 +14,7 @@
 
 from pipelines.nodes.preprocessor.base import BasePreProcessor
 from pipelines.nodes.preprocessor.preprocessor import PreProcessor
+from pipelines.nodes.preprocessor.text_splitter import (
+    CharacterTextSplitter,
+    RecursiveCharacterTextSplitter,
+)
